@@ -447,7 +447,7 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 							  &password, &passwordType) == false)
 		{
 			/*
-			 * We do not have any passeord, we can still get the password
+			 * We do not have any password, we can still get the password
 			 * from client using plain text authentication if it is
 			 * allowed by user
 			 */
@@ -984,7 +984,7 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 	else if (!rtn || frontend->pwd_size == 0)
 	{
 		/*
-		 * We do not have any passeord, we can still get the password
+		 * We do not have any password, we can still get the password
 		 * from client using plain text authentication if it is
 		 * allowed by user
 		 */
@@ -1042,7 +1042,7 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 		if (size != backend->pwd_size)
 			ereport(ERROR,
 					(errmsg("clear text password authentication failed"),
-					 errdetail("password does not match")));
+					 errdetail("password size does not match")));
 
 		if (memcmp(pwd, backend->password, backend->pwd_size) != 0)
 			ereport(ERROR,
@@ -1124,7 +1124,7 @@ authenticate_frontend_SCRAM(POOL_CONNECTION * backend, POOL_CONNECTION * fronten
 	if (!shadow_pass)
 		ereport(ERROR,
 				(errmsg("authentication failed"),
-				 errdetail("faild to build the scram verifier")));
+				 errdetail("failed to build the scram verifier")));
 
 	/*
 	 * SASL auth is not supported for protocol versions before 3, because it
