@@ -58,7 +58,7 @@ typedef struct
 	char	   *relname;
 	int			num_params;		/* num of original params (for Parse) */
 	bool		rewrite_to_params;	/* true if timestamp is rewritten to param
-									 * insread of const */
+									 * instead of const */
 	bool		rewrite;		/* has rewritten? */
 	List	   *params;			/* list of additional params */
 }			TSRewriteContext;
@@ -256,7 +256,7 @@ relcache_lookup(TSRewriteContext * ctx)
 	return (TSRel *) pool_search_relcache(ts_relcache, ctx->backend, table_name);
 }
 
-/* If timestamp valus is required then return ts_const. Otherwize make
+/* If timestamp value is required then return ts_const. Otherwise make
  * a new ParamRef, whose number member is 0 and is overwritten at last,
  * and add it into params list in context.
  */
@@ -782,7 +782,7 @@ rewrite_timestamp_update(UpdateStmt *u_stmt, TSRewriteContext * ctx)
 /*
  * Rewrite `now()' to timestamp literal.
  * If rewrite_to_params is false then, we rewrite `now()' to timestamp constant.
- * Otherwize, we rewrite `now()' to params and expand that at Bind message.
+ * Otherwise, we rewrite `now()' to params and expand that at Bind message.
  * returns query string as palloced string, or NULL if not to need rewrite.
  */
 char *
@@ -939,7 +939,7 @@ rewrite_timestamp(POOL_CONNECTION_POOL * backend, Node *node,
 		/*
 		 * CREATE TABLE t1 AS SELECT now();
 		 */
-		if (IsA(c_stmt->query, SelectStmt) && c_stmt->relkind == OBJECT_TABLE)
+		if (IsA(c_stmt->query, SelectStmt) && c_stmt->objtype == OBJECT_TABLE)
 		{
 			/* rewrite params */
 			raw_expression_tree_walker(
@@ -987,7 +987,7 @@ rewrite_timestamp(POOL_CONNECTION_POOL * backend, Node *node,
 		return NULL;
 
 	/*
-	 * PREPARE or Parse: handle additinal parameters for timestamps
+	 * PREPARE or Parse: handle additional parameters for timestamps
 	 */
 	if (ctx.rewrite_to_params && message)
 	{
@@ -1105,14 +1105,14 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL * backend,
 	{
 		/*
 		 * If num_formats is 0, the original message has no parameters or the parameter formats are all text,
-		 * so we don't need additional format codes since timestamp parametes use text as its format.
+		 * so we don't need additional format codes since timestamp parameters use text as its format.
 		 */
 		num_formats_new = 0;
 	}
 	else
 	{
 		/* If num formats is 1, this means the specified format code is applied for all original parameters,
-		 * so enlarge message length to specify format codes for each of original paramters. */
+		 * so enlarge message length to specify format codes for each of original parameters. */
 		if (num_formats == 1)
 			*len += (num_org_params - 1) * sizeof(int16);
 
@@ -1144,7 +1144,7 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL * backend,
 				copy_to += sizeof(int16);
 			}
 		}
-		/* otherwize, copy the original format codes as they are*/
+		/* otherwise, copy the original format codes as they are*/
 		else
 		{
 			copy_len = num_formats * sizeof(int16);
