@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2022	PgPool Global Development Group
+ * Copyright (c) 2003-2024	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -856,10 +856,12 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "watchdog user monitoring pgpools in lifecheck", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+#ifdef NOT_USED					/* for security reason */
 	StrNCpy(status[i].name, "wd_lifecheck_password", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->wd_lifecheck_password);
 	StrNCpy(status[i].desc, "password for watchdog user in lifecheck", POOLCONFIG_MAXDESCLEN);
 	i++;
+#endif
 
 	for (j = 0; j < MAX_WATCHDOG_NUM; j++)
 	{
@@ -1452,11 +1454,11 @@ get_pools(int *nrows)
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
 			int idle_duration = pi->connection_info[pool * MAX_NUM_BACKENDS].client_idle_duration;
-			int cliet_idle_time = pool_config->client_idle_limit;
+			int client_idle_time = pool_config->client_idle_limit;
 
 			if (pool_config->client_idle_limit > 0)
 			{
-				cliet_idle_time = pool_config->client_idle_limit - idle_duration;
+				client_idle_time = pool_config->client_idle_limit - idle_duration;
 			}
 
 			for (backend_id = 0; backend_id < NUM_BACKENDS; backend_id++)
@@ -1521,8 +1523,8 @@ get_pools(int *nrows)
 				{
 					snprintf(pools[lines].client_idle_duration, sizeof(pools[lines].client_idle_duration),
 							 "%d (%d:%02d before client disconnected)", idle_duration,
-							 cliet_idle_time / 60,
-							 cliet_idle_time % 60);
+							 client_idle_time / 60,
+							 client_idle_time % 60);
 				}
 				else
 					snprintf(pools[lines].client_idle_duration, sizeof(pools[lines].client_idle_duration),
@@ -1729,8 +1731,6 @@ processes_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 	num_fields = sizeof(field_names) / sizeof(char *);
 	processes = get_processes(&nrows);
 
-	send_row_description(frontend, backend, num_fields, field_names);
-
 	send_row_description_and_data_rows(frontend, backend, num_fields, field_names, offsettbl,
 									   (char *)processes, sizeof(POOL_REPORT_PROCESSES), nrows);
 
@@ -1765,8 +1765,6 @@ version_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 	num_fields = sizeof(field_names) / sizeof(char *);
 	version = get_version();
 
-	send_row_description(frontend, backend, num_fields, field_names);
-
 	send_row_description_and_data_rows(frontend, backend, num_fields, field_names, offsettbl,
 									   (char *)version, sizeof(POOL_REPORT_VERSION), nrows);
 
@@ -2350,7 +2348,7 @@ char *db_node_role(int node)
 	/*
 	 * Query whether the node is in recovery.
 	 */
-	if (get_query_result(slots, node, "SELECT pg_is_in_recovery()", &res))
+	if (get_query_result(slots, node, "SELECT pg_catalog.pg_is_in_recovery()", &res))
 	{
 		return "unknown";
 	}
